pub struct ContractTester { /* private fields */ }Expand description
Main contract testing framework
Implementations
Sourceimpl ContractTester
impl ContractTester
Sourcepub fn new() -> ContractTester
pub fn new() -> ContractTester
Create a new contract tester with default configuration
Sourcepub fn with_config(config: ContractTestConfig) -> ContractTester
pub fn with_config(config: ContractTestConfig) -> ContractTester
Create a contract tester with custom configuration
Sourcepub fn test_estimator_contract<E>(
&mut self,
estimator: &E,
) -> Result<(), SklearsError>where
E: Estimator + Clone + Debug + Fit<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>, ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>, f64>>,
<E as Fit<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>, ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>, f64>>>::Fitted: Predict<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>, ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>, f64>>,
pub fn test_estimator_contract<E>(
&mut self,
estimator: &E,
) -> Result<(), SklearsError>where
E: Estimator + Clone + Debug + Fit<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>, ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>, f64>>,
<E as Fit<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>, ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>, f64>>>::Fitted: Predict<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>, ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>, f64>>,
Test an estimator implementation against the Estimator trait contract
Sourcepub fn test_transform_contract<T>(
&mut self,
transformer: &T,
) -> Result<(), SklearsError>where
T: Clone + Debug + Transform<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>> + Fit<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>, ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>, f64>>,
<T as Fit<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>, ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>, f64>>>::Fitted: Transform<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>>,
pub fn test_transform_contract<T>(
&mut self,
transformer: &T,
) -> Result<(), SklearsError>where
T: Clone + Debug + Transform<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>> + Fit<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>, ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>, f64>>,
<T as Fit<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>, ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>, f64>>>::Fitted: Transform<ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>, f64>>,
Test a transformer implementation against the Transform trait contract
Sourcepub fn test_predict_proba_contract<P>(
&mut self,
predictor: &P,
) -> Result<(), SklearsError>
pub fn test_predict_proba_contract<P>( &mut self, predictor: &P, ) -> Result<(), SklearsError>
Test prediction probability contracts for classifiers
Sourcepub fn generate_report(&self) -> String
pub fn generate_report(&self) -> String
Generate a comprehensive test report
Sourcepub fn get_summary(&self) -> ContractTestSummary
pub fn get_summary(&self) -> ContractTestSummary
Get summary statistics for all contract tests