pub struct DocumentSimilarityKernel {
pub vectorizer: TfIdfVectorizer,
/* private fields */
}Expand description
Document similarity kernel based on cosine similarity
This kernel computes the cosine similarity between document vectors, which is commonly used in information retrieval and text classification.
K(d1, d2) = cos(θ) = (d1 · d2) / (||d1|| × ||d2||)
Fields
vectorizer: TfIdfVectorizerTF-IDF vectorizer
Implementations
Sourceimpl DocumentSimilarityKernel
impl DocumentSimilarityKernel
Sourcepub fn new(vectorizer: TfIdfVectorizer) -> Self
pub fn new(vectorizer: TfIdfVectorizer) -> Self
Create a new document similarity kernel
Sourcepub fn compute_document_similarity(
&self,
doc1_idx: usize,
doc2_idx: usize,
) -> Result<f64>
pub fn compute_document_similarity( &self, doc1_idx: usize, doc2_idx: usize, ) -> Result<f64>
Compute similarity between two document indices
Sourcepub fn get_document_vectors(&self) -> Option<&Array2<f64>>
pub fn get_document_vectors(&self) -> Option<&Array2<f64>>
Get the document vector matrix